@@ -289,6 +289,25 @@ class Reaction:
                                            self._chemicals)
         self._reaction(material_array)
     
+    def product_yield(self, product, basis=None):
+        """Return yield of product per reactant."""
+        product_index = self._chemicals.index(product)
+        product_coefficient = self._stoichiometry[product_index]
+        product_yield = product_coefficient * self.X
+        if self.basis != basis:
+            chemicals_tuple = self._chemicals.tuple
+            reactant_index = self._X_index
+            MW_reactant = chemicals_tuple[reactant_index].MW
+            MW_product = chemicals_tuple[product_index].MW
+            if basis == 'wt':
+                product_yield *= MW_reactant / MW_product
+            elif basis == 'mol':
+                product_yield *= MW_product / MW_reactant
+            else:
+                raise ValueError("basis must be either 'wt' or 'mol'; "
+                                f"not {repr(basis)}")
+        return product_yield
+    
     def adiabatic_reaction(self, stream):
         """
         React stream material adiabatically, accounting for the change in enthalpy
@@ -296,7 +315,8 @@ class Reaction:
         
         Examples
         --------
-        Note how the stream temperature changed after the reaction due to the heat of reaction:
+        Note how the stream temperature changed after the reaction due to the
+        heat of reaction:
         
         >>> import thermosteam as tmo
         >>> import thermosteam.reaction as rxn
